"{ Package: 'ctu:ircompiler' }"

LibraryDefinition subclass:#ctu_ircompiler
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'* Projects & Packages *'
!

!ctu_ircompiler class methodsFor:'documentation'!

extensionsVersion_SVN
    ^ '$Id::                                                                                                                        $'
! !

!ctu_ircompiler class methodsFor:'description'!

excludedFromPreRequisites
    "list packages which are to be explicitely excluded from the automatic constructed
     prerequisites list. If empty, everything that is found along the inheritance of any of
     my classes is considered to be a prerequisite package."

    ^ #(
    )
!

mandatoryPreRequisites
    "list packages which are mandatory as a prerequisite.
     This are packages containing superclasses of my classes and classes which
     are extended by myself.
     They are mandatory, because we need these packages as a prerequisite for loading and compiling.
     This method is generated automatically,
     by searching along the inheritance chain of all of my classes."

    ^ #(
        #'stx:libbasic'    "Behavior - extended"
        #'stx:libcomp'    "ByteCodeCompiler - extended"
    )
!

referencedPreRequisites
    "list packages which are a prerequisite, because they contain
     classes which are referenced by my classes.
     We do not need these packages as a prerequisite for loading or compiling.
     This method is generated automatically,
     by searching all classes (and their packages) which are referenced by my classes."

    ^ #(
        #'stx:goodies/refactoryBrowser/parser'    "RBArrayNode - referenced by IRDecompiler>>endCase:"
        #'stx:libcompat'    "Preferences - referenced by IRDecompiler>>addReturn:from:"
        #'stx:libtool'    "Tools::Inspector2Tab - referenced by IRFunction>>inspector2TabIRCode"
        #'stx:libwidg'    "ScrollableView - referenced by IRFunction>>inspector2TabIRCode"
    )
!

subProjects
    "list packages which are known as subprojects.
     The generated makefile will enter those and make there as well.
     However: they are not forced to be loaded when a package is loaded;
     for those, redefine requiredPrerequisites."

    ^ #(
    )
! !

!ctu_ircompiler class methodsFor:'description - contents'!

classNamesAndAttributes
    "lists the classes which are to be included in the project.
     Each entry in the list may be: a single class-name (symbol),
     or an array-literal consisting of class name and attributes.
     Attributes are: #autoload or #<os> where os is one of win32, unix,..."

    ^ #(
        "<className> or (<className> attributes...) in load order"
        IRBuilder
        IRBytecodeGenerator
        IRFunction
        IRInstruction
        IRInterpreter
        IRSequence
        IRStackCount
        #'ctu_ircompiler'
        IRAccess
        IRClosure
        IRConstant
        IRDecompiler
        IRDup
        IRJump
        IRLine
        IRMethod
        IRPop
        IRPrinter
        IRReturn
        IRSend
        IRTranslator
        IRBlockReturnTop
        IRInstVarAccess
        IRJumpIf
        IRJumpOverBlock
        IRLiteralVariableAccess
        IRTempAccess
        IRInstVarRead
        IRInstVarStore
        IRLiteralVariableRead
        IRLiteralVariableStore
        IRTempRead
        IRTempStore
    )
!

extensionMethodNames
    "list class/selector pairs of extensions.
     A correponding method with real names must be present in my concrete subclasses"

    ^ #(
        ByteCodeCompiler literalArray:
        Class binding
        Class bindingOf:
    )
! !

!ctu_ircompiler class methodsFor:'description - project information'!

companyName
    "Return a companyname which will appear in <lib>.rc"

    ^ 'CVUT FEI & Mathieu Suen'

    "Created: / 11-06-2008 / 16:50:46 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

description
    "Return a description string which will appear in vc.def / bc.def"

    ^ 'Smalltalk/X Bytecode generation library based on Squeak''s NewCompiler'

    "Created: / 11-06-2008 / 16:50:46 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

legalCopyright
    "Return a copyright string which will appear in <lib>.rc"

    ^ 'Copyright Jan Vrany & Mathieu Suen 2008'

    "Created: / 11-06-2008 / 16:50:46 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

productName
    "Return a product name which will appear in <lib>.rc"

    ^ 'NewCompiler'

    "Created: / 11-06-2008 / 16:50:46 / Jan Vrany <vranyj1@fel.cvut.cz>"
! !

!ctu_ircompiler class methodsFor:'description - svn'!

svnRepositoryUrlString
    "Return a SVN repository URL of myself.
     (Generated since 2011-04-08)
     Do not make the string shorter!!!!!! We have to use fixed-length keyword!!!!!!
    "        

    ^ '$URL::                                                                                                                        $'
!

svnRevisionNr
    "Return a SVN revision number of myself.
     This number is updated after a commit"

    ^ "$SVN-Revision:"'nil'"$"

    "Modified: / 29-10-2012 / 10:42:13 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!ctu_ircompiler class methodsFor:'documentation'!

version
    ^ '$eader: /cvs/stx/cvut/stx/goodies/newcompiler/ctu_ircompiler.st,v 1.4 2009/10/08 12:00:46 fm Exp$'
!

version_CVS
    ^ '$eader: /cvs/stx/cvut/stx/goodies/newcompiler/ctu_ircompiler.st,v 1.4 2009/10/08 12:00:46 fm Exp$'
!

version_HG

    ^ '$Changeset: <not expanded> $'
!

version_SVN
    ^ '$Id::                                                                                                                        $'
! !

